@@ -92,11 +92,11 @@ impl Backend for SpeechDispatcher {
         }
         let single_char = text.to_string().capacity() == 1;
         if single_char {
-            self.0.set_punctuation(Punctuation::All);
+            self.0.set_punctuation(Punctuation::All)?;
         }
         let id = self.0.say(Priority::Important, text);
         if single_char {
-            self.0.set_punctuation(Punctuation::None);
+            self.0.set_punctuation(Punctuation::None)?;
         }
         if let Some(id) = id {
             Ok(Some(UtteranceId::SpeechDispatcher(id)))
@@ -107,7 +107,7 @@ impl Backend for SpeechDispatcher {
 
     fn stop(&mut self) -> Result<(), Error> {
         trace!("stop()");
-        self.0.cancel();
+        self.0.cancel()?;
         Ok(())
     }
 
@@ -128,7 +128,7 @@ impl Backend for SpeechDispatcher {
     }
 
     fn set_rate(&mut self, rate: f32) -> Result<(), Error> {
-        self.0.set_voice_rate(rate as i32);
+        self.0.set_voice_rate(rate as i32)?;
         Ok(())
     }
 
@@ -149,7 +149,7 @@ impl Backend for SpeechDispatcher {
     }
 
     fn set_pitch(&mut self, pitch: f32) -> Result<(), Error> {
-        self.0.set_voice_pitch(pitch as i32);
+        self.0.set_voice_pitch(pitch as i32)?;
         Ok(())
     }
 
@@ -170,7 +170,7 @@ impl Backend for SpeechDispatcher {
     }
 
     fn set_volume(&mut self, volume: f32) -> Result<(), Error> {
-        self.0.set_volume(volume as i32);
+        self.0.set_volume(volume as i32)?;
         Ok(())
     }
 
